@@ -994,7 +994,7 @@ def rollback_ui_cmd(stage, traits_input_file, traits_output_file):
         s3_sync(
             f's3://{app["pipeline_metadata"]["deploy"]["s3_bucket"]}/versions/{app["pipeline_metadata"]["deploy"]["second_last_version_folder"]}',
             f's3://{app["pipeline_metadata"]["deploy"]["s3_bucket"]}/previous',
-            '--delete'
+            '--delete --exact-timestamps'
         )
     else:
         logging.info(f'No second last version found for ui ({app["name"]})!')
@@ -1002,14 +1002,14 @@ def rollback_ui_cmd(stage, traits_input_file, traits_output_file):
         s3_sync(
             f's3://{app["pipeline_metadata"]["deploy"]["s3_bucket"]}/versions/{app["pipeline_metadata"]["deploy"]["last_version_folder"]}',
             f's3://{app["pipeline_metadata"]["deploy"]["s3_bucket"]}/previous',
-            '--delete'
+            '--delete --exact-timestamps'
         )
 
     logging.info(f'Syncing last ui ({app["name"]}) version ({app["pipeline_metadata"]["deploy"]["last_version"]}) into (live)...')
     s3_sync(
         f's3://{app["pipeline_metadata"]["deploy"]["s3_bucket"]}/versions/{app["pipeline_metadata"]["deploy"]["last_version_folder"]}',
         f's3://{app["pipeline_metadata"]["deploy"]["s3_bucket"]}/live',
-        f'--exclude "{traits_output_file}" --delete'
+        f'--exclude "{traits_output_file}" --delete --exact-timestamps'
     )
 
     # Remove deployed version
